pub enum ExtractPolicyViolation {
NameRejected {
context: &'static str,
value: String,
},
SymbolicLink,
NativeSymlinkCreationUnsupported,
HardLink,
}Expand description
A valid member feature rejected by the selected extract::ExtractPolicy.
Variants
NameRejected
An effective member name or link target was rejected.
Fields
SymbolicLink
A symbolic-link member appeared when links are forbidden.
NativeSymlinkCreationUnsupported
A symbolic-link member requires native creation on an unsupported platform.
HardLink
A hard-link member appeared when links are forbidden.