pub struct LentPayload<'a, P> { /* private fields */ }Expand description
A member payload that keeps its lending Members cursor borrowed.
This wrapper is returned by Members::next. Its private fields prevent a
payload whose concrete type does not itself borrow the archive from being
detached from the cursor lifetime.